@@ -11,7 +11,8 @@ sub new
         hno         => 0,
         rprocess    => 0,
         wprocess    => 0,
-        cache       => {}
+        cache       => {},
+        rlock_limit => 0,
     } => ref($class) || $class;
 }
 
@@ -32,6 +33,13 @@ for my $m (qw(wlock rlock)) {
     }
 }
 
+sub rlock_limit
+{
+    my ($self, $value) = @_;
+    return $self->{rlock_limit} if @_ == 1;
+    return $self->{rlock_limit} = $value || 0;
+}
+
 sub is_wlocked
 {
     my ($self) = @_;
@@ -111,6 +119,9 @@ sub _check_mutex
 
     return;
     LOCK_RMUTEX:
+        return if $self->rlock_limit
+            and $self->{rprocess} >= $self->rlock_limit;
+
         $info = $self->{rlock}[0];
         $self->_delete_client($info->[0]);
         $self->{rprocess}++;
